"""Initial migration

Revision ID: 9daa2d43c98a
Revises: 
Create Date: 2023-07-27 10:00:00.000000

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '9daa2d43c98a'
down_revision = None
branch_labels = None
depends_on = None


def upgrade() -> None:
    # Create secrets table
    op.create_table(
        'secrets',
        sa.Column('id', sa.String(36), primary_key=True, index=True),
        sa.Column('content', sa.Text(), nullable=False),
        sa.Column('created_at', sa.DateTime(), nullable=False, server_default=sa.func.now()),
        sa.Column('expires_at', sa.DateTime(), nullable=False),
        sa.Column('is_viewed', sa.Boolean(), nullable=False, default=False),
    )
    
    # Create an index on expires_at for faster cleanup of expired secrets
    op.create_index('ix_secrets_expires_at', 'secrets', ['expires_at'])


def downgrade() -> None:
    # Drop the index
    op.drop_index('ix_secrets_expires_at', 'secrets')
    
    # Drop the table
    op.drop_table('secrets')